@@ -24,7 +24,7 @@ def fix_citations(lines, references, strict=True, file=None):
     return lines
 
 
-def fix_aux_special(lines, aux, command='\\nref', output='\cite[%s]{my_bibtex_entry}'):
+def fix_aux_special(lines, aux, command='\\nref', output='\\cite[%s]{my_bibtex_entry}'):
     # out = output %
     daux = {name: {'nicelabel': output % v['nicelabel'] } for name, v in aux.items()}
     l2 = fix_single_reference(lines, aux=daux, cmd=command, strict=True)
