@@ -17,7 +17,6 @@ def get_s(lines):
             pass
         if 'dse' in c['start_tag_args']:
             print("asdfasdfs")
-        # print(c['start_tag_args'])
         if 'nodoc' in c['start_tag_args'] and c['start_tag_args']['nodoc']:
             c['block'] = rm_docstring(c['block'])
             print("No documentation!")
@@ -26,25 +25,6 @@ def get_s(lines):
     output = {}
     for name, co in blocks.items():
         slines = [l for c in co for l in c['block']]
-        # full_strip("")
-        # c['block']['args']
-        # slines = slines[ 23]
-        # co.
-
-
-
-        # if slines[f.lineno].strip().startswith('"' * 3):
-        #     print("got a docstrnig")
-        #     for k in range(f.lineno, f.end_lineno + 1):
-        #         l = slines[k] if k != f.lineno else slines[k].strip()[3:]
-        #         if l.find('"' * 3) >= 0:
-        #             break
-        # else:
-        #     k = -1
-        # if k > 0:
-        #     print("Docstring detected")
-        #     for i in range(f.lineno, k + 1):
-        #         ll2[i] = None
         output[name] = slines
     return output
 
@@ -59,7 +39,8 @@ def rm_docstring(lines):
     ll2 = slines.copy()
 
     def rm_ds(f, ll2):
-        if slines[f.lineno].strip().startswith('"' * 3):
+        lstart = slines[f.lineno].strip()
+        if lstart.startswith('"' * 3) or lstart.startswith('r' + '"' * 3):
             # print("got a docstrnig")
             for k in range(f.lineno-1, f.end_lineno + 1):
                 l = slines[k] if k != f.lineno else slines[k].strip()[3:]
