@@ -18,9 +18,10 @@ def snip_dir(source_dir,  # Sources
              license_head=None,
              censor_files=True,
              verbose=True,
+             package_base_dir=None, # When running files, this will be treated as the base of the package the file is run from.
              ):
-
-    print(f"Snipper fixing {source_dir} {cut_files=}, {censor_files=}, {output_dir=}")
+    if verbose:
+        print(f"Snipper fixing {source_dir} {cut_files=}, {censor_files=}, {output_dir=}")
     if dest_dir == None:
         dest_dir = tempfile.mkdtemp()
         print("[snipper]", "no destination dir was specified so using nonsense destination:", dest_dir)
@@ -70,19 +71,8 @@ def snip_dir(source_dir,  # Sources
     for f, accept in acceptable:
         if os.path.isdir(f) or str(f).endswith("_grade.py"):
             continue
-        # if os.path.isdir(f) or not str(f).endswith(".py") or str(f).endswith("_grade.py"):
-        #     continue
-        # if accept and str(f).endswith(".rst"):
-        #     nrem, cut = censor_file(f, run_files=run_files, run_out_dirs=output_dir, cut_files=cut_files,
-        #                             # solution_list=solution_list,
-        #                             base_path=dest_dir,
-        #                             references=references,
-        #                             license_head=license_head,
-        #                             censor_files=censor_files,
-        #                             **kwargs)
 
-            # print("rst file")
-        if accept and (str(f).endswith(".py") or str(f).endswith(".rst")):
+        if accept and (str(f).endswith(".py") or str(f).endswith(".rst") or str(f).endswith(".md")):
             # if f.endswith("rst"):
             #     pass
             solution_list = []
@@ -95,6 +85,7 @@ def snip_dir(source_dir,  # Sources
                                references=references,
                                license_head=license_head,
                                censor_files=censor_files,
+                                    package_base_dir=package_base_dir,
                                **kwargs)
             if nrem > 0 and verbose:
                 print(f"{nrem}> {f}")
